==> openjdk-17_17.0.15~5ea.orig.tar.xz: openjdk-17-17.0.15~5ea/test/jdk/tools/jimage/JImageToolTest.java <==
/*
 * Copyright (c) 2015, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
/*
 * @test
 * @library /test/lib
 * @build jdk.test.lib.process.ProcessTools
 * @summary Test to check if jimage tool exists and is working
 * @run main/timeout=360 JImageToolTest
 */

import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.Arrays;

import jdk.test.lib.process.ProcessTools;

/**
 * Basic test for jimage tool.
 */
public class JImageToolTest {
    private static void jimage(String... jimageArgs) throws Exception {
        ArrayList<String> args = new ArrayList<>();
        args.add("-ms64m");
        args.add("jdk.tools.jimage.Main");
        args.addAll(Arrays.asList(jimageArgs));

        ProcessBuilder builder = ProcessTools.createLimitedTestJavaProcessBuilder(args.toArray(new String[args.size()]));
        int res = builder.inheritIO().start().waitFor();

        if (res != 0) {
            throw new RuntimeException("JImageToolTest FAILED");
        }
    }

    public static void main(String[] args) throws Exception {
        String home = System.getProperty("java.home");
        Path jimagePath = Paths.get(home, "bin", "jimage");
        Path modulesimagePath = Paths.get(home, "lib", "modules");

        if (Files.exists(jimagePath) && Files.exists(modulesimagePath)) {
            String jimage = jimagePath.toAbsolutePath().toString();
            jimage("--version");
            System.out.println("Test successful");
         } else {
            System.out.println("Test skipped, not an images build");
         }
    }
}

==> openjdk-18_18~36ea.orig.tar.xz: openjdk-18-18~36ea/test/jdk/tools/jimage/JImageToolTest.java <==
/*
 * Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
/*
 * @test
 * @library /test/lib
 * @build jdk.test.lib.process.ProcessTools
 * @summary Test to check if jimage tool exists and is working
 * @run main/timeout=360 JImageToolTest
 */

import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.Arrays;

import jdk.test.lib.process.ProcessTools;

/**
 * Basic test for jimage tool.
 */
public class JImageToolTest {
    private static void jimage(String... jimageArgs) throws Exception {
        ArrayList<String> args = new ArrayList<>();
        args.add("-ms64m");
        args.add("jdk.tools.jimage.Main");
        args.addAll(Arrays.asList(jimageArgs));

        ProcessBuilder builder = ProcessTools.createJavaProcessBuilder(args.toArray(new String[args.size()]));
        int res = builder.inheritIO().start().waitFor();

        if (res != 0) {
            throw new RuntimeException("JImageToolTest FAILED");
        }
    }

    public static void main(String[] args) throws Exception {
        String home = System.getProperty("java.home");
        Path jimagePath = Paths.get(home, "bin", "jimage");
        Path modulesimagePath = Paths.get(home, "lib", "modules");

        if (Files.exists(jimagePath) && Files.exists(modulesimagePath)) {
            String jimage = jimagePath.toAbsolutePath().toString();
            jimage("--version");
            System.out.println("Test successful");
         } else {
            System.out.println("Test skipped, not an images build");
         }
    }
}
